@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -62,7 +62,7 @@ public:
             }
         }
         imageUrlRequester->setMimeTypeFilters(lstMimeTypes);
-        imageUrlRequester->setWindowTitle(i18n("Add Image"));
+        imageUrlRequester->setWindowTitle(i18nc("@title:window", "Add Image"));
         imageUrlRequester->setMode(KFile::File);
         q->connect(imageUrlRequester->lineEdit(), &KLineEdit::textChanged,
                    q, [this](const QString &str) {
