@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,9 +21,9 @@
 
 #include <KLocalizedString>
 #include <QPushButton>
-#include <klineedit.h>
 #include <KColorScheme>
 
+#include <QLineEdit>
 #include <QLabel>
 #include <QMenu>
 #include <QHBoxLayout>
@@ -209,7 +209,7 @@ QRegularExpression TextFindWidget::searchRegExp() const
 #endif
 QTextDocument::FindFlags TextFindWidget::searchOptions() const
 {
-    QTextDocument::FindFlags opt = nullptr;
+    QTextDocument::FindFlags opt = {};
     if (mCaseSensitiveAct->isChecked()) {
         opt |= QTextDocument::FindCaseSensitively;
     }
