@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,10 +20,10 @@
 #include "plaintexteditfindbar.h"
 #include "texteditor/commonwidget/textfindreplacewidget.h"
 
-#include <kmessagebox.h>
-#include <klineedit.h>
+#include <KMessageBox>
 #include <KColorScheme>
 
+#include <QLineEdit>
 #include <QRegularExpression>
 #include <QPlainTextEdit>
 
